@@ -16,7 +16,7 @@ class CdocsTests(unittest.TestCase):
         self.logger.debug("SET THE LEVEL TO DEBUG")
 
 
-    noise = False
+    noise = True
     def _print(self, text:str) -> None:
         if self.noise:
             print(text)
@@ -274,12 +274,52 @@ class CdocsTests(unittest.TestCase):
         self._print(f"CdocsTests.test_list_docs")
         docpath = "/app/home/teams"
         cdocs = Cdocs(PATH)
+        self._print(f"CdocsTests.test_list_docs. cdocs: {cdocs}")
         docs = cdocs.list_docs(docpath)
+        self._print(f"CdocsTests.test_list_docs: docs: {docs}")
         self.assertIsNotNone(docs, msg=f"docpath: {docpath} must not be None")
         self.assertEqual(len(docs), 3, msg=f"len(docs) at {docpath} must be 3")
-        self.assertIn("todo.xml", docs, msg=f"docs {docs} must include todo.xml")
+        self.assertIn("a.json", docs, msg=f"docs {docs} must include a.json")
 
+        self._print(f"CdocsTests.test_list_docs: listing root")
+        docs = cdocs.list_docs("/")
+        self._print(f"CdocsTests.test_list_docs: docs: {docs}")
+        self.assertIsNotNone(docs, msg=f"docpath: {docpath} must not be None")
+        self.assertEqual(len(docs), 3, msg=f"len(docs) at {docpath} must be 3")
+        self.assertIn("404a.xml", docs, msg=f"docs {docs} must include 404a.xml")
 
+        self._print(f"CdocsTests.test_list_docs: listing empty string -- which is also the root")
+        docs = cdocs.list_docs("")
+        self._print(f"CdocsTests.test_list_docs: docs: {docs}")
+        self.assertIsNotNone(docs, msg=f"docpath: {docpath} must not be None")
+        self.assertEqual(len(docs), 3, msg=f"len(docs) at {docpath} must be 3")
+        self.assertIn("404a.xml", docs, msg=f"docs {docs} must include 404a.xml")
+
+        self._print(f"CdocsTests.test_list_docs: listing bogus docpath")
+        docs = cdocs.list_docs("fish/can or cannot/fly")
+        self._print(f"CdocsTests.test_list_docs: docs: {docs}")
+        self.assertIsNotNone(docs, msg=f"docpath: {docpath} must not be None")
+        self.assertEqual(len(docs), 0, msg=f"len(docs) at {docpath} must be 0")
+
+    def test_doc_at_root(self):
+        self._print(f"CdocsTests.test_doc_at_root")
+        #
+        # we have:
+        #   /404x.html
+        #   /404
+        #   /404a.xml
+        #
+        docpath = "/#404x.html"
+        cdocs = Cdocs(PATH)
+        #self._debug()
+        self._print(f"CdocsTests.test_doc_at_root. cdocs: {cdocs}")
+        doc = cdocs.get_doc(docpath)
+        self._print(f"CdocsTests.test_doc_at_root: doc: {doc}")
+        self.assertIsNotNone(doc, msg=f"docpath: {docpath} must not be None")
+        found = doc.find("REALLY") >= 0
+        # should not be found because this root doesn't have html as a format
+        # simple pather look using its exts resulting in 404x.html.xml and 404x.html.json
+        self.assertEqual(found, False, msg=f"doc at {docpath} must not include 'REALLY'")
 
 
 
